@@ -18,17 +18,15 @@
  * Author: Alaf Azam <alafazam@gmail.com>
  */
 
-const Lang = imports.lang;
-
-var GeoJSONStyle = new Lang.Class({
-    Name: 'GeoJSONStyle',
-
-    _init: function(params) {
+const DEFAULT_LINE_WIDTH = 5;
+const DEFAULT_COLOR = '69B1FF';
 
+var GeoJSONStyle = class GeoJSONStyle {
+    constructor(params) {
         if (params.lineWidth || params.lineWidth === 0)
             this.lineWidth = params.lineWidth;
         else
-            this.lineWidth = 1;
+            this.lineWidth = DEFAULT_LINE_WIDTH;
 
         if (params.alpha || params.alpha === 0)
             this.alpha = params.alpha;
@@ -40,15 +38,13 @@ var GeoJSONStyle = new Lang.Class({
         else
             this.fillAlpha = 0.25;
 
-        this.color = this._hexToColor(params.color) || { red: 0,
-                                                         green: 0,
-                                                         blue: 0 };        
+        this.color = this._hexToColor(params.color || DEFAULT_COLOR);
         this.fillColor =  this._hexToColor(params.fillColor) || { red: 0.37,
                                                                   green: 0.62,
                                                                   blue: 0.87 };
-    },
+    }
 
-    _hexToColor: function(colorString) {
+    _hexToColor(colorString) {
         let color = null;
         
         if (!colorString)
@@ -80,7 +76,7 @@ var GeoJSONStyle = new Lang.Class({
 
         return color;
     }
-});
+};
 
 GeoJSONStyle.parseSimpleStyle = function(tags) {
     return  new GeoJSONStyle({ alpha: tags['stroke-opacity'],
